lxm3.xm\_cluster.UniversalPackage
=================================

.. currentmodule:: lxm3.xm_cluster

.. autoclass:: UniversalPackage

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~UniversalPackage.__init__
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~UniversalPackage.name
      ~UniversalPackage.entrypoint
      ~UniversalPackage.build_script
      ~UniversalPackage.build_args
      ~UniversalPackage.path
   
   